@@ -1,5 +1,5 @@
 package JSON::Path::Tokenizer;
-$JSON::Path::Tokenizer::VERSION = '1.0.1';
+$JSON::Path::Tokenizer::VERSION = '1.0.2';
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ use Readonly;
 use JSON::Path::Constants qw(:symbols :operators);
 use Exporter::Shiny 'tokenize';
 
-Readonly my $ESCAPE_CHAR      => qq{\\};
+Readonly my $ESCAPE_CHAR => qq{\\};
 Readonly my %OPERATORS => (
     $TOKEN_ROOT                => 1,    # $
     $TOKEN_RECURSIVE           => 1,    # ..
@@ -18,20 +18,27 @@ Readonly my %OPERATORS => (
     $TOKEN_SCRIPT_OPEN         => 1,    # [(
     $TOKEN_SUBSCRIPT_OPEN      => 1,    # [
     $TOKEN_SUBSCRIPT_CLOSE     => 1,    # ]
+    $TOKEN_QUOTE               => 1,    # "
 );
 
+# my $invocation = 0;
+
 # ABSTRACT: Helper class for JSON::Path::Evaluator. Do not call directly.
 
 # Take an expression and break it up into tokens
 sub tokenize {
     my $expression = shift;
-
+    #print "Tokenize \"$expression\"\n";
     my $chars = [ split //, $expression ];
 
     my @tokens;
     while ( defined( my $token = _read_to_next_token($chars) ) ) {
+
+        #        print "$invocation: Got token: $token\n";
         push @tokens, $token;
         if ( $token eq $TOKEN_SCRIPT_OPEN || $token eq $TOKEN_FILTER_OPEN ) {
+
+            #            print "$invocation: script/filter open: $token\n";
             push @tokens, _read_to_filter_script_close($chars);
         }
     }
@@ -41,63 +48,86 @@ sub tokenize {
 sub _read_to_filter_script_close {
     my $chars = shift;
 
+    #print "$invocation: read to filter script close: " . join( '', @{$chars} ) . "\n";
     my $filter;
+    my $in_quote;
     while ( defined( my $char = shift @{$chars} ) ) {
         $filter .= $char;
+        if ( $char eq $APOSTROPHE || $char eq $QUOTATION_MARK ) {
+            if ( $in_quote && $in_quote eq $char ) {
+                $in_quote = '';
+            }
+            else {
+                $in_quote = $char;
+            }
+        }
 
         last unless @{$chars};
-        last if $chars->[0] eq $RIGHT_PARENTHESIS;
+        last if $chars->[0] eq $RIGHT_PARENTHESIS && !$in_quote;
     }
     return $filter;
 }
 
 sub _read_to_next_token {
+    #$invocation++;
     my $chars = shift;
 
-    my $in_quote;
+    #print "$invocation: Get next token: " . join( '', @{$chars} ) . "\n";
+    my $in_quote = '';
     my $token;
     while ( defined( my $char = shift @{$chars} ) ) {
+
         if ( $char eq $APOSTROPHE || $char eq $QUOTATION_MARK ) {
+            #print "$invocation: Char is $APOSTROPHE or $QUOTATION_MARK. Char: $char, in_quote: $in_quote\n";
             if ( $in_quote && $in_quote eq $char ) {
                 $in_quote = '';
                 last;
             }
             $in_quote = $char;
+
+            #print "$invocation: Set \$in_quote to $in_quote\n";
             next;
         }
 
         if ( $char eq $ESCAPE_CHAR && !$in_quote ) {
+
+            #print "$invocation: Got escape char: $char\n";
             $token .= shift @{$chars};
             next;
         }
 
+        #print "Append '$char' to token '$token'\n";
         $token .= $char;
-
         next if $in_quote;
 
-        # Break out of the loop if the current character is the last one in the stream.
+ # Break out of the loop if the current character is the last one in the stream.
         last unless @{$chars};
 
-        if ( $char eq $LEFT_SQUARE_BRACKET ) {    # distinguish between '[', '[(', and '[?('
+        if ( $char eq $LEFT_SQUARE_BRACKET )
+        {    # distinguish between '[', '[(', and '[?('
             if ( $chars->[0] eq $LEFT_PARENTHESIS ) {
                 next;
             }
             if ( $chars->[0] eq $QUESTION_MARK ) {
 
-                # The below appends the '?'. The '(' will be appended in the next iteration of the loop
+# The below appends the '?'. The '(' will be appended in the next iteration of the loop
                 $token .= shift @{$chars};
                 next;
             }
         }
         elsif ( $char eq $RIGHT_PARENTHESIS ) {
 
-            # A right parenthesis should be followed by a right square bracket, which itself is a token.
-            # Append the next character and proceed.
+            #print "$invocation: Found right parenthesis\n";
+
+# A right parenthesis should be followed by a right square bracket, which itself is a token.
+# Append the next character and proceed.
             $token .= shift @{$chars};
+
+            #print "$invocation: Token is now: $token\n";
         }
         elsif ( $char eq $FULL_STOP ) {
 
-            # A full stop (i.e. a period, '.') may be the child operator '.' or the recursive operator '..'
+# A full stop (i.e. a period, '.') may be the child operator '.' or the recursive operator '..'
             $token .= shift @{$chars} if $chars->[0] eq $FULL_STOP;
         }
 
@@ -107,6 +137,10 @@ sub _read_to_next_token {
         # Similarly, if the next character is an operator, we're done
         last if $OPERATORS{ $chars->[0] };
     }
+    no warnings qw/uninitialized/;
+
+    #print "$invocation: Token: $token\n";
+    use warnings qw/uninitialized/;
     return $token;
 }
 
@@ -124,7 +158,7 @@ JSON::Path::Tokenizer - Helper class for JSON::Path::Evaluator. Do not call dire
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 AUTHOR
 
